@@ -213,7 +213,7 @@ create_newline_combo (GeditFileChooserDialog *dialog)
 static void
 create_extra_widget (GeditFileChooserDialog *dialog)
 {
-	dialog->priv->extra_widget = gtk_hbox_new (FALSE, 6);
+	dialog->priv->extra_widget = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 6);
 
 	gtk_widget_show (dialog->priv->extra_widget);
 
@@ -304,7 +304,7 @@ all_text_files_filter (const GtkFileFilterInfo *filter_info,
 			GtkSourceLanguage *lang;
 
 			lang = gtk_source_language_manager_get_language (lm, *languages);
-			g_return_val_if_fail (GTK_IS_SOURCE_LANGUAGE (lang), FALSE);
+			g_return_val_if_fail (GTK_SOURCE_IS_LANGUAGE (lang), FALSE);
 			++languages;
 
 			mime_types = gtk_source_language_get_mime_types (lang);
